<?php
/*
Plugin Name: WP Bridge PHPExcel
Plugin URI: http://devlab.isao.co.jp/assets/phpexcel/
Description: The bridge plugin for WordPress to work on the library "PHPExcel" to manipulate the Excel spreadsheet from PHP.
Version: 0.2
Author: Katsuhiko Maeno
Author URI: http://devlab.isao.co.jp/
License: GPL2 - http://www.gnu.org/licenses/gpl.txt
Text Domain: wpbpe
Domain Path: /lang
*/
/*
	Copyright 2012 Katsuhiko Maeno ( email : maenok@.isao.co.jp )

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as
	published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
/*
	Acknowledgments
	
	PHPExcel
	
	@category   PHPExcel
	@package    PHPExcel
	@copyright  Copyright (c) 2006 - 2012 PHPExcel (http://www.codeplex.com/PHPExcel)
	@license    http://www.gnu.org/licenses/old-licenses/lgpl-2.1.txt	LGPL
	@version    1.7.7, 2012-05-19
*/

define('WPBRIDGEPHPEXCEL_VERSION', '0.1');
define('WPBRIDGEPHPEXCEL_PLUGIN_URL', plugin_dir_url(__FILE__));
define('WPBRIDGEPHPEXCEL_OPTIONS_NAME', 'wpbpe_opt');

load_plugin_textdomain('wpbpe', false, '/wp-bridge-phpexcel/lang/');

$plugin_dir = WP_PLUGIN_DIR . '/' . basename(dirname(__FILE__));
define('PHPEXCEL_INCLUDE_PATH', $plugin_dir . '/Classes/');
define('PHPEXCEL_OUTPUT_PATH', WP_CONTENT_DIR . '/uploads/');

// cache and error report
//define('MAGPIE_CACHE_ON', FALSE); // Cache off
//if(!defined('MAGPIE_CACHE_AGE'))
//	define('MAGPIE_CACHE_AGE', '60*60'); // in sec, one hour
// error reporting
//error_reporting(E_ALL);

// add option-menu
function wp_bridge_phpexcel_options(){
	add_submenu_page('options-general.php', 'WP Bridge PHPExcel', 'WP Bridge PHPExcel', 'manage_options', 'wp-bridge-phpexcel-options', 'plugin_options');
}
add_action('admin_menu', 'wp_bridge_phpexcel_options');

function plugin_options(){
	$default_options = array(
		'auto_include' 		=> false,
		'lib_include_path' 		=> PHPEXCEL_INCLUDE_PATH,
		'lib_output_path' 		=> PHPEXCEL_OUTPUT_PATH
	);
	$options = (array) get_option(WPBRIDGEPHPEXCEL_OPTIONS_NAME);
	$update = 0;
	if(strtolower($_SERVER['REQUEST_METHOD']) == 'post'){
		foreach($_REQUEST as $query => $value){
			$options[$query] = $value;
			$update++;
		}
	}
	$options = array_merge($default_options, $options);
	update_option(WPBRIDGEPHPEXCEL_OPTIONS_NAME, $options);
?>
<div id="wbpe_option_panel">
<div id="icon-options-general" class="icon32"></div>
<h2 style="padding-top: 15px;"><?php echo __("WP Bridge PHPExcel Options", 'wpbpe'); ?></h2>
<p id="wbpe_description" style="clear: both; line-height: 2em;"><?php echo __("This plugin can built-in \"PHPExcel\" library into WordPress. This configuration page, perform the various settings when embedding the library.", 'wpbpe'); ?></p>
<form method="post" action="">
<ul id="wbpe_option_list">
	<li><label class="caption"><?php echo __("PHPExcel automatic include: ", 'wpbpe'); ?></label>
		<input type="radio" name="auto_include" id="auto_include_true" value="true" <?php if($options['auto_include'] == 'true') echo 'checked="checked"'; ?> /><label for="auto_include_true"><?php echo __("Yes"); ?></label>
		<input type="radio" name="auto_include" id="auto_include_false" value="false" <?php if($options['auto_include'] == 'false') echo 'checked="checked"'; ?> /><label for="auto_include_false"><?php echo __("No"); ?></label>
	</li>
	<li><label class="caption"><?php echo __("PHPExcel include path: ", 'wpbpe'); ?></label>
		<input type="text" name="lib_include_path" value="<?php echo $options['lib_include_path']; ?>" style="min-width: 480px;" /></li>
	<li><label class="caption"><?php echo __("PHPExcel output files path: ", 'wpbpe'); ?></label>
		<input type="text" name="lib_output_path" value="<?php echo $options['lib_output_path']; ?>" style="min-width: 480px;" /></li>
</ul>
<?php
	if($update > 0) echo '<p class="well">' . __("options saved.", 'wpbpe') . '</p>';
?>
<div id="wbpe_option_btn"><input type="submit" class="button-primary" value="<?php echo __("Save"); ?>"></div>
</form>
<hr />
<p>
	<?php echo __("The shortcode available in the current version is as follows.", 'wpbpe'); ?>
	<div class="shortcode-strings">[inc-phpexcel] (<?php echo __("Include an arbitrary PHPExcel library. If you have already does not include anything already.", 'wpbpe'); ?>)</div>
	<div class="shortcode-strings">[conv-xls file="(<?php echo __("path of uploaded Excel file", 'wpbpe'); ?>)" type="(xls|xlsx|csv|html|pdf)" target="(<?php echo __("Target attribute of the anchor-link tag", 'wpbpe'); ?>" title="(<?php echo __("Title attribute of the anchor-link tag", 'wpbpe'); ?>" rel="(<?php echo __("Rel attribute of the anchor-link tag", 'wpbpe'); ?>"](<?php echo __("Nested content is the elements of the anchor-link tag. The default file name will be inserted automatically.", 'wpbpe'); ?>)[/conv-xls]</div>
</p>
</div>
<?php
}

function auto_include_phpexcel(){
	$options = get_option(WPBRIDGEPHPEXCEL_OPTIONS_NAME);
	if($options['auto_include'] == 'true'){
		require_once $options['lib_include_path'] . 'PHPExcel.php';
		require_once $options['lib_include_path'] . 'PHPExcel/IOFactory.php';
	}
}
add_action('init', 'auto_include_phpexcel');

function include_phpexcel(){
	$options = get_option(WPBRIDGEPHPEXCEL_OPTIONS_NAME);
	if($options['auto_include'] == 'false'){
		require_once $options['lib_include_path'] . 'PHPExcel.php';
		require_once $options['lib_include_path'] . 'PHPExcel/IOFactory.php';
	}
}
add_shortcode('inc-phpexcel', 'include_phpexcel');

function convert_excel($atts, $content = null){
	extract(shortcode_atts(array(
		'file' => '', // excel file path
		'type' => 'csv', 
		'target' => '_blank', 
		'title' => '', 
		'rel' => ''
	), $atts));
	$options = get_option(WPBRIDGEPHPEXCEL_OPTIONS_NAME);
	if($options['auto_include'] == 'false'){
		require_once $options['lib_include_path'] . 'PHPExcel.php';
		require_once $options['lib_include_path'] . 'PHPExcel/IOFactory.php';
	}
	$docroot = $_SERVER['DOCUMENT_ROOT'] . '/';
	if(isset($file) && $file != ''){
		if(file_exists($docroot . $file)){
			$ftime = date('U', filemtime($docroot . $file));
			$ary = explode('.', $file);
			$ftype = strtolower(end($ary));
			if($ftype == 'xls'){
				$rtype = 'Excel5';
			}elseif($ftype == 'xlsx'){
				$rtype = 'Excel2007';
			}elseif($ftype == 'csv'){
				$rtype = 'CSV';
			}else{
				return false;
			}
			array_pop($ary);
			$path = explode('/', implode('.', $ary));
			$filename = end($path);
			$outfilename = "_{$ftime}_{$filename}";
			if(strtolower($type) == 'csv'){
				$outfilename .= '.csv';
				$outtype = 'CSV';
			}elseif(strtolower($type) == 'xls'){
				$outfilename .= '.xls';
				$outtype = 'Excel5';
			}elseif(strtolower($type) == 'xlsx'){
				$outfilename .= '.xlsx';
				$outtype = 'Excel2007';
			}elseif(strtolower($type) == 'html'){
				$outfilename .= '.html';
				$outtype = 'HTML';
			}elseif(strtolower($type) == 'pdf'){
				$outfilename .= '.pdf';
				$outtype = 'PDF';
			}else{
				return false;
			}
			if(!file_exists($options['lib_output_path'] . $outfilename)){
				$reader = PHPExcel_IOFactory::createReader($rtype);
				$excel = $reader->load($file);
				$excel->setActiveSheetIndex(0);
				$sheet = $excel->getActiveSheet();
				$writer = PHPExcel_IOFactory::createWriter($excel, $outtype);
				$writer->save($options['lib_output_path'] . $outfilename);
			}
			$cstr = (!empty($content)) ? $content : $outfilename;
			return '<a href="' . str_replace($docroot, '', $options['lib_output_path']) . $outfilename . '" target="' . $target . '" title="' . $title . '" rel="' . $rel . '">' . $cstr . '</a>' . "\n";
		}
	}
}
add_shortcode('conv-xls', 'convert_excel');
?>